% Subroutine avg_ctr_4
%
% Prepares models using average capital tax rate data.
% General model y=rho*W*y + X*beta +u; u=lambda*W*u + e;
%
% "Strategic Interaction in Tax Policies Among States"
% by Ruben Hernandez-Murillo. (2003)
%

dos('copy empty.txt actr_4.txt');
diary actr_4.txt
mat_types1={'border','crone'};
mat_types2={'pop','gravity','features'};
num_w=8;
y_var='Avg_CTR';
x_vars={'Population','Population_Density','Urban','Unemployment','Percapita_RPI','Pct_Elderly','Pct_Young','Avg_Precipitation','Avg_Temperature'};

% Get variables. 
[Y,X] = stacks(Data,y_var,x_vars);
% Change Variables to logs.
X(:,2)=log(X(:,2));    % log population
X(:,3)=log(X(:,3));    % log pop_density
X(:,4)=log(X(:,4));    % log pct urban
X(:,5)=log(X(:,5));    % log pct unemployment
X(:,6)=log(X(:,6));    % log percapita real personal income
Xwork=100.0-X(:,7)-X(:,8);
Xwork=log(Xwork);      % log pct working age
X(:,9)=log(X(:,9));    % log of average precipitation
X(:,10)=log(X(:,10));  % log of average temperature

d=[1 2 4 5 6 10];
X=[X(:,d) Xwork];

% Log of tax rate
Y=log(Y*100);

% Estimation

fstime=clock;
% 1.- OLS on pooled data. y = X*beta + e;
% Assumes e~N(0,sigma2*I)

disp(['Starting OLS...'])
actr_ols= ols(Y,X);
disp('Finished OLS.')
tols=clock;


% 2.- y=rho*W*y + X*beta +u, u=lambda*Wu + e;

iter=1;
for i=1:3;
for j=1:4;


if j==3
	warning off
end
if j==1
	warning on
end;
time0(iter,:)=clock; 
disp('***************************************')
disp(['Iteration=',num2str(iter),' out of 11.'])
disp('***************************************')
disp(['Creating Weights  matrix...'])
% Get matrix


if i<3
Wa = sweights(mat_types1{i},'actr',Data,W0,W0text,BEA_Regions,Crone_Regions,0);
end;

if j>1
Wb = sweights(mat_types2{j - 1},'actr',Data,W0,W0text,BEA_Regions,Crone_Regions,0);
end;

if j==1 & i<3;
W=normw(Wa);
elseif j>1 & i<3; 
W=normw(Wa.*Wb);
elseif i==3;
B=logical(eye(size(W)));
Wb(B)=0;
W=normw(Wb);
end;


disp('Finished creating Weights matrix.')
tw(iter,:)=clock;

if i<3
ii=i;jj=j-1;
else
ii=0;jj=j-1;
end;

if i==3 & j==1;
disp('Empty case')
else

% 1.1- LM test for rho=0 and lambda=0
% Anselin's Robust estimators.
disp(['Starting LM OLS...'])
eval(['actr_lm_ols_w',noblanks(num2str([ii,jj])),'= lm_ols(Y,X,W,actr_ols);']);
disp('Finished LM_OLS')
tlmols(iter,:)=clock;

% 2.0- KR(93) estimation
disp(['Starting K+R (1993)...'])
eval(['[actr_krob_w',noblanks(num2str([ii,jj])),' Dhat]= kelejian(Y,X,W);']);
disp('Finished Kelejian and Robinson (1993).')
tkrob(iter,:)=clock;

% 2.1- Saavedra's LM test

disp(['Starting LM Saavedra based on Kelejian+Robinson'' results... '])
eval(['actr_lm_saa_w',noblanks(num2str([ii,jj])),'=lm_saa(Y,X,W,Dhat);']);
disp('Finished LM_Saavedra.')
%disp('**************************************')
clear Dhat
tlmsaa(iter,:)=clock;


iter=iter+1;
end;

end;
end;

for i=1:iter-1;
	actr_times(i,:)=[etime(tw(i,:),time0(i,:)) etime(tlmols(i,:),tw(i,:)) etime(tkrob(i,:),tlmols(i,:)) etime(tlmsaa(i,:),tkrob(i,:))];
end;

disp('Time elapsed broken down by activity:')
actr_times2=[actr_times sum(actr_times,2)];
disp(['Total time by matrix in minutes: '])
actr_times(:,end)./60 
disp(['Total time in minutes=', num2str(sum(actr_times2(:,end))./60)])

fendtime=clock;
disp(['total time of estimation=', num2str(etime(fendtime,fstime)./60)]);

save actr_results_4
diary off