% Descriptive statistics for
%
% "Strategic Interaction in Tax Policies Among States"
% by Ruben Hernandez-Murillo. (2003)
%


% don't use logs for summary statistics

y_var='Avg_CTR';
x_vars={'Population','Population_Density','Urban','Unemployment','Percapita_RPI','Pct_Elderly','Pct_Young','Avg_Precipitation','Avg_Temperature'};

% Get variables. No government variables in this case.
[Y,X] = stacks(Data,y_var,x_vars);
% Change Variables to logs.
X(:,2)=log(X(:,2));    % log population
X(:,3)=log(X(:,3));    % log pop_density
X(:,4)=log(X(:,4));    % log pct urban
X(:,5)=log(X(:,5));    % log pct unemployment
X(:,6)=log(X(:,6));    % log percapita real personal income
Xwork=100.0-X(:,7)-X(:,8);
Xwork=log(Xwork);      % log pct working age
X(:,9)=log(X(:,9));    % log of average precipitation
X(:,10)=log(X(:,10));  % log of average temperature

d=[2 3 4 5 6 10];

X=[X(:,d) Xwork];
X1=X;


Y=log(Y*100);
Y1=Y;

% don't use logs for summary statistics

X1=exp(X1);
Y1=exp(Y1);


NN=49;
TT=23;

for i=1:TT
	y1_mean(i,1) =  mean(Y1(NN*(i-1)+1:NN*i));
	y1_std(i,1)  =   std(Y1(NN*(i-1)+1:NN*i));
	X1_mean(i,:) =  mean(X1(NN*(i-1)+1:NN*i,:));
	X1_std(i,:)  =   std(X1(NN*(i-1)+1:NN*i,:));

end;

y1_mean = mean(y1_mean);

y1_std = mean(y1_std);

y1_min=min(Y1);
y1_max=max(Y1);

X1_mean=mean(X1_mean);

X1_std=mean(X1_std);

X1_min=min(X1);
X1_max=max(X1);

% variable list is:

% 1 Population
% 2 Population Density
% 3 pct urban
% 4 pct unemployment
% 5 percapita real personal income
% 6 pct working age
% 7 average temperature

form='%s\n';
fid=fopen('des_stat_actr.tex','w');
fprintf(fid,form,'\begin{tabular}{lrrrr}');
fprintf(fid,form,'\hline');
fprintf(fid,form,'\hline');
fprintf(fid,form,'\multicolumn{5}{c}{Summary Statistics. Period 1977-1999} \\');
fprintf(fid,form,'\hline');
fprintf(fid,form,'Variable & Mean & Min & Max & St. Dev. \\');
fprintf(fid,form,'\hline');

fprintf(fid,form,['Average Capital Tax Rate  & ',n2ss(y1_mean),' & ',n2ss(y1_min),' & ',n2ss(y1_max),' & ',n2ss(y1_std),' \\']);

fprintf(fid,form,'\hline');

fprintf(fid,form,['Population    &',n2ss(X1_mean(:,1)),' & ',n2ss(X1_min(:,1)),' & ',n2ss(X1_max(:,1)),' & ',n2ss(X1_std(:,1)),' \\']);
fprintf(fid,form,'\hline');
fprintf(fid,form,['Population density    &',n2ss(X1_mean(:,2)),' & ',n2ss(X1_min(:,2)),' & ',n2ss(X1_max(:,2)),' & ',n2ss(X1_std(:,2)),' \\']);
fprintf(fid,form,'\hline');
fprintf(fid,form,['Percent of Urban Population  &',n2ss(X1_mean(:,3)),' & ',n2ss(X1_min(:,3)),' & ',n2ss(X1_max(:,3)),' & ',n2ss(X1_std(:,3)),' \\']);
fprintf(fid,form,'\hline');
fprintf(fid,form,['Percent Unemployment  &',n2ss(X1_mean(:,4)),' & ',n2ss(X1_min(:,4)),' & ',n2ss(X1_max(:,4)),' & ',n2ss(X1_std(:,4)),' \\']);
fprintf(fid,form,'\hline');
fprintf(fid,form,['Percapita Real Personal Income  &',n2ss(X1_mean(:,5)),' & ',n2ss(X1_min(:,5)),' & ',n2ss(X1_max(:,5)),' & ',n2ss(X1_std(:,5)),' \\']);
fprintf(fid,form,'\hline');
fprintf(fid,form,['Percent of Working-age Population  &',n2ss(X1_mean(:,6)),' & ',n2ss(X1_min(:,6)),' & ',n2ss(X1_max(:,6)),' & ',n2ss(X1_std(:,6)),' \\']);
fprintf(fid,form,'\hline');
fprintf(fid,form,['Average Monthly Temperature &',n2ss(X1_mean(:,7)),' & ',n2ss(X1_min(:,7)),' & ',n2ss(X1_max(:,7)),' & ',n2ss(X1_std(:,7)),' \\']);
fprintf(fid,form,'\hline');
fprintf(fid,form,'\end{tabular}');

fclose(fid);

