function d = dlat_long(varargin)

% ===================================================================
% NAME: dlat_long.m
% PURPOSE: Produces the distance in US miles between two sets 
% of lat/long points, using to the "Haversine formula":
% 
% R. W. Sinnott, "Virtues of the Haversine," 
% Sky and Telescope, vol. 68, no. 2, 1984, p. 159. 
% See http://mathforum.org/library/drmath/view/51879.html
%
% Vectors X=[lat1 long1] and Y=[lat2 long2] are originally expressed
% in decimal degrees, so they are converted to radians
%
% Ruben Hernandez-Murillo. 2003
% ===================================================================

n=length(varargin);

if n==2

x=varargin{1};
y=varargin{2};

lat1=x(1)*pi/180;
lon1=x(2)*pi/180;

lat2=y(1)*pi/180;
lon2=y(2)*pi/180;

dlon=lon2-lon1;
dlat=lat2-lat1;
a=(sin(dlat/2))^2+cos(lat1)*cos(lat2)*(sin(dlon/2))^2;
c=2*atan2(sqrt(a),sqrt(1-a));
d=3956*c;

elseif n==1

X=varargin{1};

% The following code ripped from PDIST.M in the Mathworks statistics toolbox

[m, n] = size(X);

if m < 2
   error('The first argument has to be a numerical matrix with at least two rows');
end

p = (m-1):-1:2;
I = zeros(m*(m-1)/2,1);
I(cumsum([1 p])) = 1;
I = cumsum(I);
J = ones(m*(m-1)/2,1);
J(cumsum(p)+1) = 2-p;
J(1)=2;
J = cumsum(J);

% End of rip-off

lat1=X(I,1)*pi/180;
lon1=X(I,2)*pi/180;

lat2=X(J,1)*pi/180;
lon2=X(J,2)*pi/180;

dlon=lon2-lon1;
dlat=lat2-lat1;
a=((sin(dlat./2)).^2)+cos(lat1).*cos(lat2).*((sin(dlon./2)).^2);
c=2*atan2(sqrt(a),sqrt(1-a));
d=3956*c';

d=squareform(d);
else
 disp('Wrong number of arguments')
end;
