function lm = lm_saa(y,x,W,Rhat)

% NAME: lm_saa.m. Saavedra's (2003) LM statistics for 
%       Kalejian-Robinson (1993)/ Kalejian-Prucha (1996)
%       full spatial lag/autocorrelation model.
% PURPOSE: Computes LM statistic using restricted-GMM residuals for
%          H0: rho==0, 
%          H1: rho~=0.
% REQUIRES: Rhat matrix from Kelejian-Robinson(1993) GMM estimator (kelejian.m)
% PROVIDES: lm structure with test statistics and p-values
%
% Ruben Hernandez-Murillo (2003)

XR = x'*Rhat*x;

XRI = (XR)\eye(size(XR));

gamma_breve =XRI*x'*Rhat*y;

Wy = W*y; 

u_breve= y - x*gamma_breve;

Jrho = Wy'*Rhat*Wy - Wy'*Rhat*x*XRI*x'*Rhat*Wy;

lm.stat = (u_breve'*Rhat*Wy)^2/Jrho;

lm.prob = 1 -  chi2cdf(lm.stat,1);

lm.crit1 = 6.6349;





