% Load Data
% "Strategic Interaction in Tax Policies Among States"
% by Ruben Hernandez-Murillo. (2003)
%
% ===================================================================
% Geo-Demographics
% ===================================================================

tic
[data textdata]=xlsread('Data','population');
for i=1:49; 
  Data.Population(i).state=textdata(i+1); 
  Data.Population(i).var=data(:,i+1); 
  Data.Population(i).time=data(:,1); 
  Data.Population(i).dates=[num2str(data(1,1)),'-',num2str(data(end,1))];
end;

[data textdata]=xlsread('Data','pct_young');
for i=1:49; 
  Data.Pct_Young(i).state=textdata(i+1); 
  Data.Pct_Young(i).var=data(:,i+1); 
  Data.Pct_Young(i).time=data(:,1); 
  Data.Pct_Young(i).dates=[num2str(data(1,1)),'-',num2str(data(end,1))];
end;

[data textdata]=xlsread('Data','pct_elderly');
for i=1:49; 
  Data.Pct_Elderly(i).state=textdata(i+1); 
  Data.Pct_Elderly(i).var=data(:,i+1); 
  Data.Pct_Elderly(i).time=data(:,1); 
  Data.Pct_Elderly(i).dates=[num2str(data(1,1)),'-',num2str(data(end,1))];
end;

[data textdata]=xlsread('Data','pct_urban');
for i=1:49; 
  Data.Pct_Urban(i).state=textdata(i+1); 
  Data.Pct_Urban(i).var=data(:,i+1); 
  Data.Pct_Urban(i).time=data(:,1); 
  Data.Pct_Urban(i).dates=[num2str(data(1,1)),'-',num2str(data(end,1))];
end;

% Fill between years
I=[2,3*ones(1,10),4*ones(1,10),5*ones(1,10),6*ones(1,2)]';
B=[Data.Pct_Urban.var];
BB=B(I,:);
for i=1:49;
  Data.Urban(i).state=Data.Pct_Urban(i).state;
  Data.Urban(i).var=BB(:,i);
  Data.Urban(i).time=(1969:2001)';
  Data.Urban(i).dates=Data.Pct_Urban(i).dates;
end;

clear I B BB
[data textdata]=xlsread('Data','centroids');
for i=1:49; 
  Data.Centroids(i).state=textdata(i+2); 
  Data.Centroids(i).lat=data(find(data(:,2)==1),i+2);
  Data.Centroids(i).lon=data(find(data(:,2)==2),i+2); 
  Data.Centroids(i).time=data(find(data(:,2)==1),1); 
  Data.Centroids(i).dates=[num2str(data(1,1)),'-',num2str(data(end,1))];
end;

% Compute Population Centers for entire sample assuming the coordinates 
% remain the same throughout the decade following the census year

time=Data.Population(1).time;
I=[2,3*ones(1,10),4*ones(1,10),5*ones(1,10),6*ones(1,2)]';
Alat=[Data.Centroids.lat];
Alon=[Data.Centroids.lon];
Blat=Alat(I,:);
Blon=Alon(I,:);

for i=1:49; 
  Data.Population_Center(i).state=textdata(i+2);
  Data.Population_Center(i).lat=Blat(:,i);
  Data.Population_Center(i).lon=Blon(:,i);
  Data.Population_Center(i).time=time;
  Data.Population_Center(i).dates=[num2str(time(1)),'-',num2str(time(end))];
end;

clear time I Alat Alon Blat Blon

%% Computed Population Centers

[data textdata]=xlsread('Data','sq_miles');
for i=1:49; 
  Data.Sq_miles(i).state=textdata(i+1); 
  Data.Sq_miles(i).var=data(:,i+1); 
  Data.Sq_miles(i).time=data(:,1); 
  Data.Sq_miles(i).dates=[num2str(data(1,1)),'-',num2str(data(end,1))];
end;


% Compute Population Density by year using same sq_miles for decade 
% following census year Except for 1969 which uses the same sq_miles as 1970

time=Data.Population(1).time;
I=[1,ones(10,1)',2*ones(10,1)',3*ones(10,1)',4*ones(2,1)']';
A=[Data.Sq_miles.var];
B=([Data.Population.var]);
AA=A(I,:);
BB=B./AA;

for i=1:49; 
  Data.Population_Density(i).state=textdata(i+1); 
  Data.Population_Density(i).var=BB(:,i); 
  Data.Population_Density(i).time=time; 
  Data.Population_Density(i).dates=[num2str(data(1,1)),'-',num2str(data(end,1))];
end;

clear I A B AA BB time

% Computed Population density

[data textdata]=xlsread('Data','precipitation');
for i=1:49; 
  Data.Avg_Precipitation(i).state=textdata(i+1); 
  Data.Avg_Precipitation(i).var=data(:,i+1); 
  Data.Avg_Precipitation(i).time=data(:,1); 
  Data.Avg_Precipitation(i).dates=[num2str(data(1,1)),'-',num2str(data(end,1))];
end;

[data textdata]=xlsread('Data','temperature');
for i=1:49; 
  Data.Avg_Temperature(i).state=textdata(i+1); 
  Data.Avg_Temperature(i).var=data(:,i+1); 
  Data.Avg_Temperature(i).time=data(:,1); 
  Data.Avg_Temperature(i).dates=[num2str(data(1,1)),'-',num2str(data(end,1))];
end;

% ===================================================================
% Economic Indicators
% ===================================================================

[data textdata]=xlsread('Data','personal_income');
for i=1:size(data,2)-1; 
  Data.Personal_Income(i).state=textdata(i+1); 
  Data.Personal_Income(i).var=data(:,i+1); 
  Data.Personal_Income(i).time=data(:,1); 
  Data.Personal_Income(i).dates=[num2str(data(1,1)),'-',num2str(data(end,1))];
end;


[data textdata]=xlsread('Data','real_personal_income');
for i=1:49; 
  Data.Real_Personal_Income(i).state=textdata(i+1); 
  Data.Real_Personal_Income(i).var=data(:,i+1); 
  Data.Real_Personal_Income(i).time=data(:,1); 
  Data.Real_Personal_Income(i).dates=[num2str(data(1,1)),'-',num2str(data(end,1))];
end;

[data textdata]=xlsread('Data','percapita_rpi');
for i=1:49; 
  Data.Percapita_RPI(i).state=textdata(i+1); 
  Data.Percapita_RPI(i).var=data(:,i+1); 
  Data.Percapita_RPI(i).time=data(:,1); 
  Data.Percapita_RPI(i).dates=[num2str(data(1,1)),'-',num2str(data(end,1))];
end;

[data textdata]=xlsread('Data','unemployment');
for i=1:49; 
  Data.Unemployment(i).state=textdata(i+1); 
  Data.Unemployment(i).var=data(:,i+1); 
  Data.Unemployment(i).time=data(:,1); 
  Data.Unemployment(i).dates=[num2str(data(1,1)),'-',num2str(data(end,1))];
end;

% ===================================================================
% Tax Variables
% ===================================================================

%% 1.- Panel Variables

[data textdata]=xlsread('Data','avg_ctr');
for i=1:(size(data,2)-1); 
  Data.Avg_CTR(i).state=textdata(1,i+1); 
  Data.Avg_CTR(i).var=data(:,i+1); 
  Data.Avg_CTR(i).time=data(:,1); 
  Data.Avg_CTR(i).dates=[num2str(data(1,1)),'-',num2str(data(end,1))];
end;

clear data textdata

% ===================================================================
% Variables Used to Compute Average Capital Tax Rate
% ===================================================================

[data textdata]=xlsread('Data','corporate_revenues');
for i=1:(size(data,2)-1)/4;
	Data.Corp_Revenues(i).state=textdata(1,4*(i-1)+2);
	Data.Corp_Revenues(i).CI=data(:,4*(i-1)+2);
	Data.Corp_Revenues(i).CT=data(:,4*(i-1)+3);
	Data.Corp_Revenues(i).PT=data(:,4*(i-1)+4);
	Data.Corp_Revenues(i).Tp=data(:,4*(i-1)+5);
	Data.Corp_Revenues(i).time=data(:,1);
	Data.Corp_Revenues(i).dates=[num2str(data(1,1)),'-',num2str(data(end,1))];
end;

clear data textdata

% ===================================================================
% Baic Contiguity Spatial Matrix
% ===================================================================

[W0 textdata]=xlsread('Data','contiguity');
W0text=textdata(2:end,1);

clear textdata
% ===================================================================

t0=toc
;
disp(['loaded data in ',num2str(t0),' seconds.'])

clear t0
% ===================================================================
% BEA and Crone's Regions
% ===================================================================

regions


