function [Y,X] = stacks(Data,y_var,x_vars,varargin)

% ===================================================================
% NAME: stacks.m
% PURPOSE: stacks data for the pooled regression: Y is NTx1, X is NTxK 
% CALL: [Y X]= stacks(Data,'dependent_variable',{'first_rhs','second_rhs'},[])
%
% Usage:
% y_var: string with the name of the dependent variable
% x_vars: cell array of strings with the names of right-hand side variables 
% varargin: (optional) relevant if using the state public finances database
% varargin{1}=DatGov, a structure with the database 
% varargin{2}=g_vars, cell array of string with rhs variable names
%
% "Strategic Interaction in Tax Policies Among States"
% by Ruben Hernandez-Murillo. (2003)
%
% ===================================================================

if length(varargin)==0

% Figure out model from name of dependent variable
switch y_var

case 'Avg_CTR'

time00=(1977:1999)';
T=length(time00);
time0=[Data.Avg_CTR(1).time];
states0=[Data.Avg_CTR.state]';
N=length(states0);
K=length(x_vars);
[junk I0]=setdiff(time0,setdiff(time0,time00));
yt=[Data.Avg_CTR.var];
yt=yt(I0,:);
Y=vec(yt');
X=ones(N*T,1);
for j=1:length(x_vars);
	eval(['time',num2str(j),'=[Data.',char(x_vars{j}),'(1).time];']);
	eval(['[junk I',num2str(j),']=setdiff(time',num2str(j),',setdiff(time',num2str(j),',time00));']);
	eval(['xt_',num2str(j),'=[Data.',char(x_vars{j}),'.var];']);
	eval(['states',num2str(j),'=[Data.',char(x_vars{j}),'.state];']);
	% In this case we know length(states0)>=length(statesj) So:
	eval(['J',num2str(j),'=charindx(states',num2str(j),',states0);']);
	eval(['xt_',num2str(j),'=xt_',num2str(j),'(I',num2str(j),',J',num2str(j),')'';']);
%	eval(['size(xt_',num2str(j),')']);
	eval(['X=[X vec(xt_',num2str(j),')];']);
end;

otherwise
	error('Dependent variable name not recognized')
	
end;

else
DatGov=varargin{1};
g_vars=varargin{2};

switch y_var


case 'Avg_CTR'

time00=(1977:1999)';
T=length(time00);
time0=[Data.Avg_CTR(1).time];
states0=[Data.Avg_CTR.state]';
N=length(states0);
K=length(x_vars);
[junk I0]=setdiff(time0,setdiff(time0,time00));
yt=[Data.Avg_CTR.var];
yt=yt(I0,:);
Y=vec(yt');
X=ones(N*T,1);
for j=1:length(x_vars);
	eval(['time',num2str(j),'=[Data.',char(x_vars{j}),'(1).time];']);
	eval(['[junk I',num2str(j),']=setdiff(time',num2str(j),',setdiff(time',num2str(j),',time00));']);
	eval(['xt_',num2str(j),'=[Data.',char(x_vars{j}),'.var];']);
	eval(['states',num2str(j),'=[Data.',char(x_vars{j}),'.state];']);
	% In this case we know length(states0)>=length(statesj) So:
	eval(['J',num2str(j),'=charindx(states',num2str(j),',states0);']);
	eval(['xt_',num2str(j),'=xt_',num2str(j),'(I',num2str(j),',J',num2str(j),')'';']);
%	eval(['size(xt_',num2str(j),')']);
	eval(['X=[X vec(xt_',num2str(j),')];']);
end;
clear xt_*

for j=1:length(g_vars);
	eval(['time',num2str(j),'=[DatGov.',char(g_vars{j}),'(1).time];']);
	eval(['[junk I',num2str(j),']=setdiff(time',num2str(j),',setdiff(time',num2str(j),',time00));']);
	eval(['xt_',num2str(j),'=[DatGov.',char(g_vars{j}),'.var];']);
	eval(['states',num2str(j),'=[DatGov.',char(g_vars{j}),'.state];']);
	% In this case we know length(states0)>=length(statesj) So:
	eval(['J',num2str(j),'=charindx(states',num2str(j),',states0);']);
	eval(['xt_',num2str(j),'=xt_',num2str(j),'(I',num2str(j),',J',num2str(j),')'';']);
%	eval(['size(xt_',num2str(j),')']);
	eval(['X=[X vec(xt_',num2str(j),')];']);
end;


otherwise
disp('Can only use government public finance from 1977')

end;

end;
